C##INCLUDE##  IMPLICIT_NONE
      IMPLICIT NONE
C####END####
C##INCLUDE##  LRL_NODMAX
      INTEGER NODHKL_MAX
      PARAMETER (NODHKL_MAX=12)
C
C Maximum nodal index (absolute) for which a spot will be considered to
C be a nodal
C####END####
C##INCLUDE##  LRL_MAXSS
      INTEGER MAX_SPOTS_IN_STRIP
      PARAMETER (MAX_SPOTS_IN_STRIP=10000)
C
C Maximum allowed number of spots in a strip for overlaps searching
C####END####
C##INCLUDE##  LRL_DATA
C
C====== Parameter statements
C
      INTEGER MAX_REF
      PARAMETER (MAX_REF=100000)

C MAX_REF  Maximum number of predicted reflections which may be generated
C
C====== Global parameters for the reflection list
C
      COMMON /LRL_A/ NUM_SPOTS, NSING, NMULT, 
     +               NUM_REFLEX, NTRIES, LASTHKL(3),
     +               NUM_SPAT, NUM_CLOS,
     +               XSTART, XEND,
     +               INTEGRATED, DISTOR_CORR,
     +               OVLAP_STATUS, ISORT, INTCODE_TYPE
      INTEGER        NUM_SPOTS, NSING, NMULT
      INTEGER        NUM_REFLEX, NTRIES, LASTHKL
      INTEGER        NUM_SPAT, NUM_CLOS
      REAL           XSTART, XEND
      LOGICAL        INTEGRATED, DISTOR_CORR
      INTEGER        OVLAP_STATUS, ISORT, INTCODE_TYPE
      SAVE /LRL_A/
C
C NUM_SPOTS          Number of predicted spots in list.
C NSING              Number of singles
C NMULT              Number of multiples
C NUM_REFLEX         Number of reflections (allowing for components of
C                    multiples).
C NTRIES             Number of reflections tried during generation
C XSTART             Lowest XD value for a predicted spot
C XEND               Highest XD value for a predicted spot
C LASTHKL            Indices of last reflection predicted
C NUM_SPAT           No. of spots marked as spatially overlapped
C NUM_CLOS           No. of spots marked as too close to attempt
C                    spatial deconvolution during integration.
C INTEGRATED         =.TRUE.  Integrated intensities have been input
C                    =.FALSE. No integrated intensities have been input
C DISTOR_CORR        =.TRUE.  Stored coordinates are distortion corrected
C                             (normal case)
C                    =.FALSE. Stored coordinates are not distortion
C                             corrected
C OVLAP_STATUS       = 0, none calculated
C                    = 1, analytical calculation (spot + unused
C                         pixel + border) v spot
C                    = 2, analytical calculation (spot + border) v spot
C                    = 3, analytical calculation spot v spot
C                    = 4, mask method (spot + unused pixel + border) v spot
C                    = 5, mask method (spot + border) v spot
C                    = 6, mask method spot v spot
C ISORT              Current sort order (via INDX array)
C                    = 0,  none
C                    = 1,  sorted on k, k, l
C                    = 2,  sorted on nodal h, k, l
C                    = 3,  sorted on XD
C                    = 4,  sorted on YD
C                    = 5,  sorted on lambda
C                    = 6,  sorted on dmin_thr2
C INTCODE_TYPE       Indicates the nature of the integration program
C                    dependent integration status code being used.
C                    = 0  not known to the 'LRL' routines
C                    > 0  a known type (LRL routines will be supplied
C                         to handle these when devised)
C                         ** none as of present **
C
C====== Saved values of selected parameters used in current reflection
C       generation
C
      COMMON /LRL_B/ IPK, IPL, GLMIN, GLMAX, GDMIN,
     +               LMIN_NEW, LMAX_NEW, DMIN_NEW, DTHR2_NEW,
     +               GXCEN, GYCEN, GMM_RAST_X, GMM_RAST_Y,
     +               GCOS_WC, GSIN_WC, GCTOF
      INTEGER        IPK, IPL
      REAL                     GLMIN, GLMAX, GDMIN
      REAL           LMIN_NEW, LMAX_NEW, DMIN_NEW, DTHR2_NEW
      REAL           GXCEN, GYCEN, GMM_RAST_X, GMM_RAST_Y
      REAL           GCOS_WC, GSIN_WC, GCTOF
      SAVE /LRL_B/
C
C IPK          Pack number
C IPL          Plate number
C GLMIN        Lambda-min
C GLMAX        Lambda-max
C GDMIN        Dmin
C LMIN_NEW     Re-assigned lambda-min
C LMAX_NEW     Re-assigned lambda-max
C DMIN_NEW     Re-assigned dmin
C DTHR2_NEW    1/(DMIN_NEW)**2
C GXCEN        Corrected 'x' centre in rasters (0.0 if x_cen_f, y_cen_f not set)
C GYCEN        Corrected 'y' centre in rasters (0.0 if x_cen_f, y_cen_f not set)
C GMM_RAST_X   Conversion factor from mm to x-raster units
C GMM_RAST_Y   Conversion factor from mm to y-raster units
C GCOS_WC      cos(w_c)
C GSIN_WC      sin(w_c)
C GCTOF        c_to_f used in generation
C
C
C====== Main Laue Reflection List (LRL) arrays
C
      COMMON /LRL_C/ HKL(MAX_REF), XF_D(MAX_REF), YF_D(MAX_REF), 
     +               LAMBDAS(MAX_REF), DMIN_THR2 (MAX_REF),
     +               MULTS(MAX_REF), NOD_HKL(MAX_REF),
     +               AII(MAX_REF), SIGII(MAX_REF),
     +               FLAGS(MAX_REF), INDX(MAX_REF),
     +               IWORK1(MAX_REF), IWORK2(MAX_REF)
      INTEGER        HKL
      REAL                         XF_D,          YF_D
      REAL           LAMBDAS,          DMIN_THR2
      INTEGER        MULTS,          NOD_HKL
      REAL           AII,          SIGII
      INTEGER        FLAGS,          INDX
      INTEGER        IWORK1,          IWORK2
      SAVE /LRL_C/

C HKL           Packed indices 2**20*(h+512) + 2**10*(k+512) + l + 512
C XF_D          Predicted x-coordinates of spots on detector in mm's from
C               centre of predicted pattern (normally corrected for
C               distortion but may not be (see DISTOR_CORR flag)
C YF_D          Predicted y-coordinates of spots on detector in mm's from
C               centre of predicted pattern (normally corrected for
C               distortion but may not be (see DISTOR_CORR flag)
C LAMBDAS       Lambda values in Angstroms (for multiple spots is lambda
C               for the minimum harmonic present)
C DMIN_THR2     (Dmin threshold)**2 values in Angstroms (for multiple spots 
C               the value for the minimum harmonic present)
C MULTS         Multiplicity/harmonics list flags. 
C                          =0 not yet assigned (local to reflection 
C                             generation routines)
C                          =1 single
C                          >1 2**20*multiplicity + 2**12*mimimum-harmonic
C                             + 2**4*maximum-harmonic + harmonic increment
C NOD_HKL       Packed nodal indices (packed as for HKL)
C AII           Integrated intensities for the spots
C SIGII         Sig(I) values for the spots
C FLAGS         Bit 0   Spatially overlapped flag 1=yes, 2=no
C               Bit 1   Spot too close to attempt deconvolution 1=yes, 0=no
C                       (Will also be marked as spatially overlapped)
C               Bit 2   Spatially overlapped flag for re-assigned data
C               Bit 3   Spot too close flag for re-assigned data
C               Bit 4   Non-overlapped nodal flag
C               Bit 8   Spot measured (integrated) flag 1=yes, 0=no
C               Bit 9   Bad spot flag (set when spot is integrated)
C                       1=bad, 0=good
C               Bit 10  Overload flag 1=yes, 0=no
C               Bits 12-19  Integration program dependent flag with codes
C                           indicating status of integrated intensity.
C                           INTCODE_TYPE is non-zero, then a standard
C                           code known to the LRL routines is being used.
C               Bit 20      No. of overload pixels set =1 yes, =0 no
C               Bits 21-28  Number of overloaded pixels in spot (0-255)
C                           255 = 255 or more pixels are overloaded
C   
C INDX          Pointers for current sort order
C IWORK1        Work array for LRL routines used by: LRL_OVLP
C                                                    LRL_XDLSIM
C IWORK2        Work array for LRL routines used by: LRL_XDLSIM
C
C####END####
C**EOF**
