C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LRL_STATUS       **
C**************************
C
CD-Routine: Return Status of Laue Reflection List - LRL_STATUS
C This routine returns status information from the Laue Reflection
C List including the number of spots, the current sort order, the
C spatial overlap criterion, whether or not the coordinates were
C distortion corrected and whether or not intensity integration has
C been carried out.
CD-end
CD-Fortran:
      SUBROUTINE LRL_STATUS (NUMSPOTS, ISORTED, IOVTYP, DISTOR, 
     +                       INTEG, INTCOD)
CD-end
      INCLUDE 'implicit_none.finc'
C
C Purpose: Return status flags from the Laue Reflection List (LRL)
C
C Author:  John W. Campbell, July 1993
C
C Arguments:
C
      INTEGER NUMSPOTS
      INTEGER ISORTED
      INTEGER IOVTYP
      LOGICAL DISTOR
      LOGICAL INTEG
      INTEGER INTCOD
CD-Parameters:
C NUMSPOTS   i (W)  The number of spots in the Laue Reflection List
C ISORTED    i (W)  Sort order 0 = none
C                              1 = sorted on h, k, l
C                              2 = sorted on nodal h, k, l
C                              3 = sorted on 'xfd'
C                              4 = sorted on 'yfd'
C                              5 = sorted on lambda
C                              6 = sorted on dminthr2
C IOVTYP    i (W)    Overlaps calculation option used (0=none calculated)
C                    (Value as used in call to LRL_GEN)
C DISTOR    l (W)    Distortion correction flag 
C                    = .true.  distortion correction was applied to stored
C                              coordinates
C                    = .false. distortion correction was not applied
C                    Note: LRL_GET routine returns distortion corrected 
C                          coordinates in either case; LRL_GET_XFYFD will
C                          return stored coordinates.
C INTEG     l (W)   Integration done flag =.true. yes, =.false. no
C INTCOD    i (W)   Integration code type flag = 0 if not known to the
C                   LRL routines.
C                   =1 Integration using Q. Hao's routine LFN_SAINT as
C                      used in INTLDM/LAUEGEN
CD-end
C====== GLOBALS:
C
      INCLUDE 'lrl_data.finc'
C
C====== FUNCTION TYPES:
C
      EXTERNAL LRL_BDAT
C
C-------------------------------------------------------------------------------
C
      NUMSPOTS = NUM_SPOTS
      ISORTED = ISORT
      IOVTYP = OVLAP_STATUS
      DISTOR = DISTOR_CORR
      INTEG = INTEGRATED
      INTCOD = INTCODE_TYPE
      RETURN
      END
