
C LAST UPDATE:
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C***************************
C**     LSC_ANALYSES      **
C***************************
C
CD-Routine: Calculates and outputs statistical data - LSC_ANALYSES
C This routine calculates and prepares various statistical graphs and
C marks reflections as outliers according to the input cutoff criteria.
CD-end
CD-Fortran:
C
      SUBROUTINE LSC_ANALYSES (LINDX, REFERENCE, IFL1, IFL2, IFL3, 
     +                        EXOUT, CUTOFF)
CD-end
C
      INCLUDE 'implicit_none.finc'
C
C
C Purpose : Carries out data diagnostics
C
C Author:  Steffi Arzt, John Campbell, July 1997
C
C Arguments:
C
      INTEGER LINDX
      INTEGER IFL1
      INTEGER IFL2
      INTEGER IFL3
      REAL CUTOFF
      LOGICAL EXOUT
      LOGICAL REFERENCE

CD-Parameters:
C
C   LINDX     i  (R)    The index of the Laue Integrated Reflections List
C   REFERENCE l  (R)    If .true. then only reflections which have a
C                       reference intensity stored will be returned;
C                       if .false., reflections will be returned whether
C                       or not a reference intensity is present.
C   IFL1,IFL2 i  (R)    Output flags
C                       IFL1 = 0, IFL2 = 0
C                       no windows output
C                       IFL1 = 1, IFL2 = 1
C                       internal refinement, no refset
C                       IFL1 = -1, IFL2 = 1
C                       external refinement, refset
C                       IFL1 = 1, IFL2 = -1
C                       internal refinement, refset scaling
C   IFL3      i  (R)    If > 0, write text files listing points, with
C                       standard names 'error_before.txt', 'error_after.txt',
C                       'Ioversig_vs_lam.txt', 'resn_vs_lam.txt',
C                       'Ioversig_vs_resn.txt', 'norm_curve.txt',
C                       'Ilaue_vs_Iref.txt'.
C   CUTOFF    r  (R)    Outlier cutoff
C   EXOUT     l  (R)    Outlier exclusion flag (if .true. then exclude outliers)
CD-end

C 
C====== PARAMETERS:
C
      INCLUDE 'limits.finc'
C
C====== GLOBALS:
C
      INCLUDE 'scale_presets.finc'
      INCLUDE 'use_reflns.finc'
      INCLUDE 'scp.finc'
      INCLUDE 'ref_flags.finc'
      INCLUDE 'other_scale.finc'
      INCLUDE 'view_handles.finc'
C
C====== FUNCTION TYPES:
C
      INTEGER LSM_NEXT_REFLN
      INTEGER LSM_INDX
      INTEGER XDLSTR
      INTEGER LSM_NORM_RANGE
      DOUBLE PRECISION LSM_ANORM
      INTEGER LENSTR, KDMSTR
C
C====== LOCALS:
C

      INTEGER I, J, K1, K2, KN, NR
      INTEGER KERR, IERR
      INTEGER KSYM
      INTEGER IPACK, IPLATE
      INTEGER KPLS
      INTEGER IUSE
      INTEGER IH, IK, IL
      INTEGER M_SCAT1 
      INTEGER M_SCAT2
      INTEGER M_IOSLAM
      INTEGER M_RESLAM 
      INTEGER M_IOSRES 
      INTEGER M_NORM 
      INTEGER M_ILOIR
      INTEGER NVIEW
      INTEGER IVHLIST(2)
      INTEGER IVH
      INTEGER ITEM
      INTEGER IQUIT
      INTEGER KNORM
      INTEGER SPAT_OUT, OVLD_OUT, NEGINT
      INTEGER JUN, NWBIN(1000)
      INTEGER MAXE, INT_TYPE, ITYP, ISTAT

      REAL ANR
      REAL REFINT
      REAL ALAM
      REAL AI, SIGMA
      REAL AIBOX, SIGIBOX
      REAL SC
      REAL ABSCOR_NU, PSI_LOC, PSI_GLO
      REAL STOL2, AL3C2T, ABSCOR_LAMFN
      REAL OB_LPFAC
      REAL SCALINT(MAX_SYMEQ),SCALSIG(MAX_SYMEQ)
      REAL ALAMS(MAX_SYMEQ)
      REAL AINT(MAX_SYMEQ)
      REAL AREFMEAN(MAX_SYMEQ)
      REAL AIMEAN, ASIGMEAN, AMEAN
      REAL AIMEAN1, ASIGMEAN1, AMEAN1
      REAL ERROR(MXR)
      REAL ERROR1(MXR)
      REAL ALBDA(MXR)
      REAL ALAMBDA(MXR)
      REAL STOL(MAX_SYMEQ)
      REAL RES(MXR)
      REAL IOSIG(MXR)
      REAL WLNORM(MXR)
      REAL RFINT(MXR), SCINT(MXR)
      REAL SIGOUT
      REAL R, ALAMMIN, ALAMMAX, ALAMINT, WBINS(1000)
      LOGICAL SPOV, OVLD
      LOGICAL GRAPH_DISP 
      LOGICAL OPN
      CHARACTER*23 NAMES(7)
      CHARACTER*19 NAMESEX(2)
      CHARACTER*25 QUITNAM
      CHARACTER*20 FILOUT(7)
      CHARACTER*8 VALSTR
      CHARACTER*80 ERRSTR, STR

      DATA NAMES /'Error before refinement',
     +            'Error after refinement',
     +            'I/sig(I) vs. lambda',
     +            'resolution vs. lambda',
     +            'I/sig(I) vs. resolution',
     +            'Normalisation curve',
     +            'ILaue vs IRef'/
      DATA NAMESEX /'Error after Scaling',
     +              'ILaue vs IRef'/
      DATA QUITNAM /'Return to Previous Menu'/
      DATA FILOUT /'error_before.txt', 'error_after.txt',
     +             'Ioversig_vs_lam.txt', 'resn_vs_lam.txt',
     +             'Ioversig_vs_resn.txt', 'norm_curve.txt',
     +             'Ilaue_vs_Iref.txt'/

      MAXE = LEN(ERRSTR)
      K1 = 0
      K2 = 0
      GRAPH_DISP = .FALSE.
      JUN = 10
      IF (IFL3.GT.0) THEN
    5   INQUIRE (UNIT=JUN,OPENED=OPN)
        IF (OPN) THEN
          JUN = JUN + 1
          IF (JUN.LE.99) GO TO 5
        ENDIF
      ENDIF
      DO 40 I = 1, MXR
         ERROR(I) = 0.0
         ERROR1(I) = 0.0
         ALBDA(I) = 0.0
         ALAMBDA(I) = 0.0
         RES(I) = 0.0
         IOSIG(I) = 0.0
         WLNORM(I) = 0.0
         RFINT(I) = 0.0
         SCINT(I) = 0.0
 40   CONTINUE

      DO 50 I = 1, MAX_SYMEQ
         SCALINT(I) = 0.0
         SCALSIG(I) = 0.0
         ALAMS(I) = 0.0
         AINT(I) = 0.0
         AREFMEAN(I) = 0.0
         STOL(I) = 0.0
 50   CONTINUE

      CALL LSM_SEL_SAVE

      CALL LSM_SELECT_PKPL (0, 0) 

C>>>>

      CALL LSC_GET_OUTPUTFLAGS (LINDX, OVLD_OUT, SPAT_OUT,  
     +                          NEGINT, SIGOUT)      

C>>>>>
      IF (SPAT_OUT.EQ.1) SPOV = .TRUE.
      IF (SPAT_OUT.EQ.0) SPOV = .FALSE.
      IF(OVLD_OUT.NE.0) THEN
         OVLD = .TRUE.
      ELSE
         OVLD = .FALSE.
      END IF      

      CALL LSM_SELECT_SCREFS (.FALSE., REFERENCE, SIGOUT,  
     +                        SPOV, OVLD) 
    
      CALL LSM_TOP_LIRL(LINDX, KERR)

      IF (KERR.NE.0) RETURN 

      CALL LSM_CALC_PRESETS 

 10   NR = LSM_NEXT_REFLN(KERR)

      IF (NR.LE.-1) THEN
         CALL LSM_SEL_RESTORE

         IF (IFL1.NE.0.AND.IFL2.NE.0) THEN

            IF (REFERENCE.AND.IFL1.LT.0) THEN
               CALL XDLF_MENU_AREA_SETMENU (IVH_MENU, 7,  
     +           XDLSTR(NAMES),23, 
     +           XDLSTR('Refinement against refset'), 25,
     +           XDLSTR(QUITNAM), 25, 0, IERR)
            ELSE IF (IFL1.GT.0.AND.IFL2.LT.0) THEN
               CALL XDLF_MENU_AREA_SETMENU (IVH_MENU, 7,  
     +              XDLSTR(NAMES),23, 
     +              XDLSTR('Internal refinement'), 19,
     +              XDLSTR(QUITNAM), 25, 0, IERR)
            ELSE 
               CALL XDLF_MENU_AREA_SETMENU (IVH_MENU, 6,  
     +              XDLSTR(NAMES),23, 
     +              XDLSTR('Internal refinement'), 19,
     +              XDLSTR(QUITNAM), 25, 0, IERR)
            END IF
               M_SCAT1 = 1
               M_SCAT2 = 2
               M_IOSLAM = 3
               M_RESLAM = 4
               M_IOSRES = 5
               M_NORM = 6
               M_ILOIR = 7
C
C====== Set up list of view-object handles
C
            NVIEW = 1
            IVHLIST(1) = IVH_MENU
C
C====== Start event loop
C
 500        CALL XDLF_GET_EVENTS (NVIEW, IVHLIST, IVH)
            IF (IVH.EQ.IVH_MENU) THEN
C
C======  Menu item selected
C
               CALL XDLF_MENU_AREA_GETITEM (IVH_MENU, ITEM, IQUIT)
C
C======  Quit selected
C
               IF (IQUIT.EQ.1) THEN
                  IF (GRAPH_DISP) THEN
                     CALL XDLF_GRAPH_WIN_DELETE (IVH_GRAPH, 0, IERR)
                  END IF
                  RETURN
               END IF

               IF(ITEM.EQ.M_SCAT2) THEN
                  CALL LSC_SCATTER (1, 1, ALBDA, ERROR, K2, 1)
                  GRAPH_DISP = .TRUE.
                  IF (IFL3.GT.0) THEN
                    OPEN (UNIT=JUN,FILE=FILOUT(2))
                    DO 101 I=1,K2,IFL3
                    WRITE (10,1001) ALBDA(I),ERROR(I)
  101               CONTINUE
 1001               FORMAT (2F10.4)
                    CLOSE (JUN)
                  ENDIF
                  GO TO 500
               ELSE IF (ITEM.EQ.M_SCAT1) THEN
                  CALL LSC_SCATTER(1, 1, ALBDA, ERROR1, K2, -1)
                  GRAPH_DISP = .TRUE.
                  IF (IFL3.GT.0) THEN
                    OPEN (UNIT=JUN,FILE=FILOUT(1))
                    DO 102 I=1,K2,IFL3
                    WRITE (10,1001) ALBDA(I),ERROR1(I)
  102               CONTINUE
                    CLOSE (JUN)
                  ENDIF
                  GO TO 500
               ELSE IF (ITEM.EQ.M_IOSLAM) THEN
                  CALL LSC_SCATTER (1, 2, ALAMBDA, IOSIG, K1, 1)
                  GRAPH_DISP = .TRUE.
                  IF (IFL3.GT.0) THEN
                    OPEN (UNIT=JUN,FILE=FILOUT(3))
                    DO 103 I=1,K1,IFL3
                    WRITE (10,1002) ALAMBDA(I),IOSIG(I)
  103               CONTINUE
 1002               FORMAT (F10.4,F10.2)
                    CLOSE (JUN)
                  ENDIF
                  GO TO 500
               ELSE IF (ITEM.EQ.M_RESLAM) THEN
                  CALL LSC_SCATTER (1, 3, ALAMBDA, RES, K1, 1)
                  GRAPH_DISP = .TRUE.
                  IF (IFL3.GT.0) THEN
                    OPEN (UNIT=JUN,FILE=FILOUT(4))
                    DO 104 I=1,K1,IFL3
                    WRITE (10,1003) ALAMBDA(I),RES(I)
  104               CONTINUE
 1003               FORMAT (F10.4,F10.6)
                    CLOSE (JUN)
                  ENDIF
                  GO TO 500
               ELSE IF (ITEM.EQ.M_IOSRES) THEN
                  CALL LSC_SCATTER (2, 2, RES, IOSIG, K1, 1)
                  GRAPH_DISP = .TRUE.
                  IF (IFL3.GT.0) THEN
                    OPEN (UNIT=JUN,FILE=FILOUT(5))
                    DO 105 I=1,K1,IFL3
                    WRITE (10,1004) RES(I),IOSIG(I)
  105               CONTINUE
 1004               FORMAT (F10.6,F10.2)
                    CLOSE (JUN)
                  ENDIF
                  GO TO 500
               ELSE IF (ITEM.EQ.M_NORM) THEN
                  CALL LSC_SCATTER (1, 4, ALAMBDA, WLNORM, K1, 1)
                  GRAPH_DISP = .TRUE.
                  IF (IFL3.GT.0) THEN
                    DO 1051 I=1,1000
                    NWBIN(I)=0
                    WBINS(I)=0.0
 1051               CONTINUE
                    ALAMMIN = 1000.0
                    ALAMMAX = 0.0
                    DO 1052 I=1,K1
                    IF (ALAMBDA(I).LT.ALAMMIN) ALAMMIN = ALAMBDA(I)
                    IF (ALAMBDA(I).GT.ALAMMAX) ALAMMAX = ALAMBDA(I)
 1052               CONTINUE
                    ALAMINT = (ALAMMAX-ALAMMIN)*0.001
                    IF (ALAMINT.LT.0.00001) ALAMINT=0.00001
                    DO 1053 I=1,K1
                    J = ((ALAMBDA(I)-ALAMMIN)/ALAMINT)+1
                    IF (J.LT.1) J=1
                    IF (J.GT.1000) J=1000
                    NWBIN(J) = NWBIN(J)+1
                    WBINS(J)=WBINS(J)+WLNORM(I)
 1053               CONTINUE
                    OPEN (UNIT=JUN,FILE=FILOUT(6))
                    DO 106 I=1,1000
                    IF (NWBIN(I).GT.0) THEN
                      R = NWBIN(I)
                      WBINS(I)=WBINS(I)/R
                      R = I - 0.5
                      R = ALAMMIN + (ALAMINT*R)
                      WRITE (10,1001) R,WBINS(I)
                    ENDIF
  106               CONTINUE
                    CLOSE (JUN)
                  ENDIF
                  GO TO 500
               ELSE IF (ITEM.EQ.M_ILOIR) THEN
                  CALL LSC_SCATTER (3, 5, RFINT, SCINT, K1, 1)
                  GRAPH_DISP = .TRUE.
                  IF (IFL3.GT.0) THEN
                    OPEN (UNIT=JUN,FILE=FILOUT(7))
                    DO 107 I=1,K1,IFL3
                    WRITE (10,1005) RFINT(I),SCINT(I)
  107               CONTINUE
 1005               FORMAT (2F10.2)
                    CLOSE (JUN)
                  ENDIF
                  GO TO 500                  
               END IF
            END IF
            GO TO 500

         ELSE

            RETURN

         END IF
      END IF
C
      INT_TYPE = 1
      STR = 'INTENSITY_TYPE'
      CALL KDMF_GETVALSTR (KDX, KDMSTR(STR), LENSTR(STR),  
     +         1, 1, 8, KDMSTR(VALSTR), ISTAT,
     +         ITYP, KDMSTR(ERRSTR), MAXE, KERR)
      IF (KERR.EQ.0) THEN
        IF (VALSTR(1:3).EQ.'BOX') INT_TYPE = 2
        IF (VALSTR(1:3).EQ.'COM') INT_TYPE = 3
      ENDIF
C
      AIMEAN = 0.0
      AMEAN = 0.0
      ASIGMEAN = 0.0
      AIMEAN1 = 0.0
      AMEAN1 = 0.0
      ASIGMEAN1 = 0.0

      DO 240 I = 1, NR
         CALL LIRLF_LSM_SCALOBS (LINDX,LSM_INDX(I), 
     +             IPACK, IPLATE, AI, SIGMA, AIBOX, SIGIBOX, ALAM, 
     +             REFINT, ABSCOR_NU, PSI_LOC, PSI_GLO, STOL2,
     +             AL3C2T, ABSCOR_LAMFN, OB_LPFAC,
     +             KNORM, KPLS, IUSE, KERR)
         CALL LSM_CALCSCFAC (SC, IPACK, IPLATE, KPLS, KNORM,
     +             ABSCOR_NU, PSI_LOC, PSI_GLO, ABSCOR_LAMFN,  
     +             STOL2, ALAM, AL3C2T, OB_LPFAC,  .TRUE.,
     +             PQ00_GLOB_STORE, P00_LOC_STORE, AKNORM_STORE,
     +             ANORMREF_STORE, KERR)
         IF (INT_TYPE.EQ.2) THEN
           AI=AIBOX
           SIGMA=SIGIBOX
         ELSE IF (INT_TYPE.EQ.3) THEN
           IF (SIGMA.GT.0.0) THEN
             IF ((AI/SIGMA).GT.5.0) THEN
               AI=AIBOX
               SIGMA=SIGIBOX
             ENDIF
           ENDIF
         ENDIF
         SCALINT(I) = SC*AI
         SCALSIG(I) = SC*SIGMA
         AINT(I) = AI
         ALAMS(I) = ALAM
         STOL(I) = STOL2
         IF (REFINT_USE) THEN
            AREFMEAN(I) = REFINT
         ELSE 
            IF (NR.GT.1) THEN
               AIMEAN = AIMEAN + SCALINT(I)/SCALSIG(I)**2
               ASIGMEAN = ASIGMEAN + 1/SCALSIG(I)**2
            END IF
         END IF
         IF (NR.GT.1) THEN
            AIMEAN1 = AIMEAN1 + AI/SIGMA**2
            ASIGMEAN1 = ASIGMEAN1 + 1/SIGMA**2
         END IF
         CALL LIRLF_GETHKL (LINDX, LSM_INDX(I), IH, IK, IL, KSYM, KERR)
         K1 = K1 + 1
         KN = LSM_NORM_RANGE (REFNORMLAM)
         ANR = 1.0/LSM_ANORM(KN, REFNORMLAM, KERR)
         WLNORM(K1) = 1.0/(LSM_ANORM(KNORM, ALAM, KERR) * ANR)
         IF (KERR.NE.0) THEN
            IERR = 2
         END IF
         IF (REFINT_USE.OR.IFL2.LT.0) THEN
            RFINT(K1) = REFINT
            SCINT(K1) = SCALINT(I)
         END IF         
         RES(K1) = STOL(I)
         IOSIG(K1) =  SCALINT(I)/SCALSIG(I) 
         ALAMBDA(K1) = ALAMS(I)
 240  CONTINUE

      IF (NR.EQ.1) GO TO 10

      IF (.NOT.REFINT_USE) THEN
         AMEAN = AIMEAN/ASIGMEAN
         DO 30 I = 1, NR
            AREFMEAN(I) = AMEAN
 30      CONTINUE
      END IF
      AMEAN1 = AIMEAN1/ASIGMEAN1
      DO 440 I = 1, NR       
         K2 = K2 + 1
         ERROR(K2) = (SCALINT(I)-AREFMEAN(I))/AREFMEAN(I)
         ERROR1(K2) = (AINT(I)-AMEAN1)/AMEAN1
         ALBDA(K2) = ALAMS(I)
         IF(EXOUT.AND.ABS(ERROR(K2)).GT.CUTOFF) THEN
            CALL LIRLF_SET_OUTLIER(LINDX,LSM_INDX(I),1,KERR)
            K2 = K2 - 1
         END IF
 440  CONTINUE
      GO TO 10
      
 6200 FORMAT (4F11.3,4I6,2F11.3)
 6300 FORMAT (4F12.3,3I8,F11.3)
 6400 FORMAT (5F12.3)
 6500 FORMAT (40I3)
 6600 FORMAT (25I4)

      END
