
C LAST UPDATE:
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C***************************
C**     LSM_REFINE        **
C***************************
C
C
CD-Routine: General LSM refinement routine - LSM_REFINE
C This routine allows for a general refinement of any selection of the
C LSM scaling parameters including the global (but not local) absorption
C surface. The parameters to be refined by the current call to the
C routine are set via LSM_SET_RFLAGS (and LSM_ADD_RFLAG, LSM_CLR_RFLAG if
C required) which must be called prior to calling LSR_REFINE. The
C classes of data to be used must also be set up prior to calling
C LSM_REFINE by calls to LSM_SELECT_PKPL and LSM_SELECT_SCREFS.
CD-end
CD-Fortran:
      SUBROUTINE  LSM_REFINE (LINDX, REFERENCE, IRFTYP, TUNE, FMIN,
     +                        IERR, MESSAGE)
CD-end
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: General LSM parameter refinement routine
C
C Author:  Steffi Arzt, John Campbell, July 1997
C
C Arguments:
C
      INTEGER LINDX
      INTEGER IRFTYP
      INTEGER IERR
      REAL FMIN
      REAL TUNE(3)
      LOGICAL REFERENCE
      CHARACTER*(*) MESSAGE
C
CD-Parameters:
C  LINDX       i (R)   The index of the Laue Integrated Reflections List
C  REFERENCE   l (R)   Flag = .true.  Refine against reference data -
C                                     cf LAUESCALE.
C                                     (Must have called LSM_SELECT_SCREFS
C                                      with REFERENCE = .true.)
C              l            = .false. Refine against current scaled mean
C                                     intensities (internal scaling - cf
C                                     LAUENORM.
C  IRFTYP      i (R)   Refinement routine type =1 Use LSQMIN
C                                              =2 Use LSQMQL
C  TUNE()      r (R)   Tuning parameters specific to the refinement type
C                      If IRFTYP=1 TUNE(1) = shift limit e.g.0.001
C                                  TUNE(2) = step parameter e.g. 1.0E-10
C                                  TUNE(3) = damping factor e.g. 0.5
C                      If IRFTYP=2 TUNE(1) = tolerance (ACC)
C                                  TUNE(2) = step size (H)
C  FMIN        r (W)   The refined function value (sum of squares)
C  IERR        i (W)   Error flag = 0 OK
C                                 =-1 Too little work spce for LSQMIN - 
C                                     try LSQMQL instead
C                                 = 1 Too little work space for LSQMQL
C  MESSAGE     c (W)   Message string from refinement (up to 80 chars)
CD-end
C
C Implementation Notes: Remember to use double precision copies of
C                       TUNE parameters where needed; also FMIN here
C                       returned as a real.
C
C====== PARAMETERS:
C
      INCLUDE 'limits.finc'
C
C====== GLOBALS:
C
      INCLUDE 'ref_flags.finc'
      INCLUDE 'scps_counters.finc'
      INCLUDE 'scp.finc'
      INCLUDE 'other_scale.finc'
      INCLUDE 'refine_lsm.finc'
      INCLUDE 'x_array.finc'
C
C====== FUNCTION TYPES:
C
      EXTERNAL LSM_CALFUN
      INTEGER LSM_NUM_REFOBS
      INTEGER LSM_NORM_RANGE
      DOUBLE PRECISION LSM_ANORM
C
C====== LOCALS:
C
      LOGICAL RETRY
      INTEGER NREF
      INTEGER KERR
      INTEGER I
      INTEGER J
      INTEGER KN
      REAL ANR
      DOUBLE PRECISION FVECC(MXR)
      DOUBLE PRECISION FMINDP
      DOUBLE PRECISION W(NW) 
      DOUBLE PRECISION X(MXPAR),ER(MXPAR)
      DOUBLE PRECISION DTUNE(3)  

C          
C-------------------------------------------------------------------------------
C
      IERR = 0
      MESSAGE = ' '
C
C====== start refinement:
C
      CALL LSM_TOP_LIRL (LINDX, KERR)
 
      NREF = LSM_NUM_REFOBS (LINDX, REFERENCE)
C
C====== Clear refinement flags which use data not found to be present
C
      CALL LSM_MISSING_RFLAGS

      REFSETFLAG =  REFERENCE     

      CALL LSM_SCP_X (1,X)

      RETRY = .FALSE.
      IF (IRFTYP.EQ.1) THEN
         IF (NW.LT.(NREF+2*NXELE+3)*NXELE + 2*NREF) THEN
            IERR = -1
            MESSAGE = 
     +      'NOT SUFFICIENT WORK SPACE FOR LSQMIN _TRYING LSQMQL'
            RETRY = .TRUE.
            GO TO 10
         END IF
         DTUNE(1) = TUNE(1)
         DTUNE(2) = TUNE(2)
         DTUNE(3) = TUNE(3)
         FMINDP = FMIN
         CALL LSQMIN(NREF,NXELE,X,ER,DTUNE(1),MAXITR,DTUNE(2),
     +               DTUNE(3),LSM_CALFUN,FMINDP,FVECC,KERR,W)
         FMIN = FMINDP
         TUNE(1) = DTUNE(1)
         TUNE(2) = DTUNE(2)
         TUNE(3) = DTUNE(3)
      END IF

 10   IF (IRFTYP.EQ.2.OR.RETRY) THEN
         IF (NW.LT.(NREF+6)*NXELE + NREF) THEN
C====== Memory allocation problem
            IERR = (NREF+6)*NXELE + NREF
            RETURN
         END IF
         DTUNE(1) = TUNE(1)
         DTUNE(2) = TUNE(2)
         CALL LSQMQL(NREF,NXELE,X,DTUNE(1),DTUNE(2),LSM_CALFUN,
     +              FMINDP,FVECC,KERR,W)  
         FMIN = FMINDP
      END IF

      CALL LSM_SCP_X (2,X)
C
C====== Rescale normalisation parameters here if required
C
      IF (NORM) THEN
         KN = LSM_NORM_RANGE (REFNORMLAM)
         ANR = 1.0/LSM_ANORM(KN, REFNORMLAM, KERR)
         DO 120 I = 1, MAXRANGE
            IF (NORMRAN(I)) THEN
               DO 110 J = 1, NNORM(I)
                  SCP(NCSCP(6)+(I-1)*POLCOEFFS+J) =
     +                     ANR*SCP(NCSCP(6)+(I-1)*POLCOEFFS+J)
 110           CONTINUE
            END IF
 120     CONTINUE
      END IF

      RETURN

      END
